<?php

namespace Drupal\oauth2_rs\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\language\Plugin\LanguageNegotiation\LanguageNegotiationBrowser;

/**
 * Class UserAuthService.
 */
class UserAuthManager implements UserAuthManagerInterface {

  /**
   * Drupal\Core\Entity\EntityManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a new UserAuthService object.
   */
  public function __construct(EntityTypeManagerInterface $entityManager, ConfigFactoryInterface $configFactory) {
    $this->entityTypeManager = $entityManager;
    $this->config = $configFactory->get('oauth2_rs');
  }

  /**
   * {@inheritDoc}
   */
  public function createAccount($email, $username, $role, $language = 'en') {
    $user = $this->entityTypeManager->getStorage('user')->create([]);
    // Using password generator.
    $user->setPassword(user_password(10));
    $user->enforceIsNew();
    $user->setEmail($email);
    $user->setUsername($username);
    $user->set("langcode", $language);
    $user->set("preferred_langcode", $language);

    $user->addRole($role);

    $user->activate();
    $user->save();
    return $user;
  }

  /**
   * {@inheritDoc}
   */
  public function getUserConsumerByRole($role) {
    $clientConsumer = $this->entityTypeManager->getStorage('consumer')
      ->loadByProperties(['roles' => $role]);
    $clientConsumer = reset($clientConsumer);
    return $clientConsumer;
  }

}
